"""Class for player character, with the special abilities and all"""

import character, vector

import pygame
from pygame.locals import *

import os.path

class Player(character.Character):
    """Adds in mutate and pickup features"""
    def __init__(self, game, controller):
        self.element = "normal"
        self.controller = controller
        character.Character.__init__(self, game, "black", "res/chars/player.moves")
        self.facing = "right"
        self.speed = 8
        self.jump = -32 #remember y axis flip
        self.add_vector("right", (0, 0))
        self.add_vector("up", (0, 0))
        self.add_vector("down", (0, 0))
        self.add_vector("left", (0, 0))
        self.add_vector("space", (0, 0))
        
    def update(self):
        self.ragdoll.update("standing")
        self.image = self.ragdoll.draw()
        self.rect.size = self.image.get_rect().size
        if self.controller.keys["r"]:
            self.game.level.load(self.game.level.levname)
            self.rect.topleft = self.game.level.find_tag("spawnp")
            self.element = "normal"
            self.ragdoll.set_color("black")
            
        if self.controller.keys["z"]:
            if self.facing == "right":
                top = self.game.level.get_at(self.rect.right, self.rect.centery-(self.rect.height/4))
                bottom = self.game.level.get_at(self.rect.right, self.rect.centery+(self.rect.height/4))
            elif self.facing == "left":
                top = self.game.level.get_at(self.rect.left, self.rect.centery-(self.rect.height/4))
                bottom = self.game.level.get_at(self.rect.left, self.rect.centery+(self.rect.height/4))
            if self.element == "water":
                if top and top.tag == "pot":
                    leaf = self.game.level.get_at(top.rect.centerx, top.rect.centery-(self.game.level.scale*2))
                    leaf.animate = "true"
                elif bottom and bottom.tag == "pot":
                    leaf = self.game.level.get_at(bottom.rect.centerx, bottom.rect.centery-(self.game.level.scale*2))
                    leaf.animate = "true"
                    
            if self.element == "fire":
                if top and top.tag == "wool":
                    top.animate = "true"
                if bottom and bottom.tag == "wool":
                    bottom.animate = "true"
                    
        if self.controller.keys["right"]:
            self.facing = "right"
            self.vectors["right"] = vector.Vec2d(self.speed, 0)
            
        if not self.controller.keys["right"]:
            self.vectors["right"] = vector.Vec2d(0, 0)
            
        if self.controller.keys["left"]:
            self.facing = "left"
            self.vectors["left"] = vector.Vec2d(-self.speed, 0)
            
        if not self.controller.keys["left"]:
            self.vectors["left"] = vector.Vec2d(0, 0)
            
        if self.facing == "right":
            self.image = pygame.transform.flip(self.image, True, False)

            
        below = self.game.level.get_at(self.rect.centerx, self.rect.inflate(2, 2).bottom)
        if below and below.solid == "true":
            self.vectors["space"] = vector.Vec2d(0, 0)
            self.vectors["grav"] = vector.Vec2d(0, self.game.level.grav)
            if self.controller.keys["space"]:
                self.vectors["space"] = vector.Vec2d(0, self.jump)
        character.Character.update(self)
