"""Level management class, keeps hold of objects and level lookup functions"""

import pygame
from pygame.locals import *

import ConfigParser, os.path

import entity

class Level:
    """Level class, contains array of blocks and all live entities"""
    def __init__(self, level, game):
        self.game = game
        self.conf = ConfigParser.SafeConfigParser()
        self.load(level)
        
    def update(self):
        self.data.update()
        
    def find_tag(self, tag):
        for sprite in self.data.sprites():
            if sprite.tag == tag:
                return sprite.rect.topleft
        return (0,0)
                
    def get_at(self, x, y):
        for tile in self.data.sprites():
            if tile.rect.collidepoint(x, y):
                return tile
        return None
        
    def load(self, level):
        self.levname = level
        self.conf.readfp(open(os.path.normcase(os.path.normpath(level)))) # be friendly with windows...
        self.bgnd = pygame.Surface((640, 480))
        self.bgnd.fill(pygame.Color("white"))
        self.grav = eval(self.conf.get("meta", "grav"))
        self.scale = eval(self.conf.get("meta", "scale"))
        self.array = pygame.surfarray.array2d(pygame.image.load(self.conf.get("meta", "blockdata")))
        self.tempdata = [[entity.Block(dict(self.conf.items(str(x))), self) for x in y] for y in self.array]
        for row in range(len(self.tempdata)):
            for col in range(len(self.tempdata[0])):
                self.tempdata[row][col].rect = pygame.Rect((row*32, col*32), eval(self.tempdata[row][col].size))
        # next three lines make a 1-D list out of a 2-D list
        self.data = []
        for x in self.tempdata:
            self.data.extend(x)
        self.data = pygame.sprite.Group(self.data)
        self.tiles = eval(self.conf.get("meta", "tiles"))
        for pair in self.tiles.items():
            self.tiles[pair[0]] = pygame.image.load(os.path.normcase(os.path.normpath(pair[1])))
